| Copyright | (c) OleksandrZhabenko 2021 |
|---|---|
| License | MIT |
| Maintainer | olexandr543@yahoo.com |
| Safe Haskell | None |
| Language | Haskell2010 |
Melodics.ByteString.Ukrainian.ArrInt8
Contents
Description
Functions provide functionality of a musical instrument synthesizer or for Ukrainian speech synthesis especially for poets, translators and writers. Is rewritten from the module Melodics.ByteString.Ukrainian.Arr for optimization purposes. Phonetic material is taken from the :
Solomija Buk, Ján Mačutek, Andrij Rovenchak. Some properties of the Ukrainian writing system. [Electronic resource] https://arxiv.org/ftp/arxiv/papers/0802/0802.4198.pdf
Synopsis
- type Sound8 = Int8
- type FlowSound = [Sound8]
- convertToProperUkrainianI8 :: String -> FlowSound
- isUkrainianL :: Char -> Bool
- linkFileNameI8 :: Sound8 -> Char